# Notebook-YT-Helper
A Jupyter Notebook extension that allows users to easily embed YouTube videos directly into jupyter or google colab notebooks.


## Installation guidelines

### 1. Create a conda environment

```bash
conda create -n renderer python=3.8 -y
```

### 2. Activate the conda environment

```bash
conda activate renderer
```

### 3. Install the required packages

```bash
pip install -r requirements_dev.txt
```